// tslint:disable
import { Component, ViewChild } from "@angular/core";

import * as wjcCore from "@grapecity/wijmo";
import * as wjcGrid from "@grapecity/wijmo.grid";
import * as wjcGridFilter from "@grapecity/wijmo.grid.filter";
import * as wjcGridPdf from "@grapecity/wijmo.grid.pdf";
import * as wjcPdf from "@grapecity/wijmo.pdf";

@Component({
  selector: "app-root",
  templateUrl: "./app.component.html",
  styleUrls: ["./app.component.css"]
})
export class AppComponent {
  source: any;
  @ViewChild("grid", { static: true }) grid: wjcGrid.FlexGrid;
  @ViewChild("filter", { static: true }) filter: wjcGridFilter.FlexGridFilter;

  constructor() {
    this.source = this.getData(50);
  }

  onClick(e: MouseEvent) {
    const doc = new wjcPdf.PdfDocument({
      ended: function(
        s: wjcPdf.PdfDocument,
        e: wjcPdf.PdfDocumentEndedEventArgs
      ) {
        wjcPdf.saveBlob(e.blob, "Report.pdf");
      },
      header: {
        declarative: {
          text: "\tHeader\t&[Page]",
          font: new wjcPdf.PdfFont("helvetica", 20, "normal", "bold")
        }
      },
      footer: {
        declarative: {
          text: "\t&[Page]\\&[Pages]",
          brush: "#3173c0",
          font: new wjcPdf.PdfFont("helvetica", 20, "normal", "bold")
        }
      },
      pageSettings: {
        margins: {
          top: 20,
          left: 20,
          right: 20,
          bottom: 20
        }
      }
    });

    doc.setFont(new wjcPdf.PdfFont('helvetica', 10, 'normal', 'normal'));
    doc.moveDown();

    // draw the filter text if applied
    doc.drawText('The data is filtered according to these columns:');
    doc.moveDown();
    this.grid.columns.forEach(col => {
      if(this.filter.getColumnFilter(col).isActive) {
        doc.drawText(col.header);
        doc.moveDown();
      }
    });

    doc.moveDown();

    wjcGridPdf.FlexGridPdfConverter.draw(this.grid, doc, doc.width, null);

    doc.moveDown();
    doc.moveDown();

    // draw the signature part
    const settings: wjcPdf.IPdfTextDrawSettings = {
      font: new wjcPdf.PdfFont('helvetica', 15, 'normal', 'normal')
    }
    doc.drawText('Signature:', null, null, settings);
    doc.moveDown();
    doc.drawText('Name:', null, null, settings);
    doc.moveDown();
    doc.drawText('Date:', null, null, settings);

    doc.end();
  }

  getData(count: number) {
    let countries = "US,Germany,UK,Japan,Italy,Greece".split(","),
      data = [];
    for (let i = 0; i < count; i++) {
      data.push({
        id: i,
        country: countries[i % countries.length],
        date: new Date(2014, i % 12, i % 28),
        amount: Math.random() * 10000,
        active: i % 4 === 0
      });
    }
    return new wjcCore.CollectionView(data);
  }
}
